
package org.w3c.dom.svg;

public interface SVGFESpotLightElement extends 
               SVGElement {
  public SVGAnimatedNumber getX( );
  public SVGAnimatedNumber getY( );
  public SVGAnimatedNumber getZ( );
  public SVGAnimatedNumber getPointsAtX( );
  public SVGAnimatedNumber getPointsAtY( );
  public SVGAnimatedNumber getPointsAtZ( );
  public SVGAnimatedNumber getSpecularExponent( );
  public SVGAnimatedNumber getLimitingConeAngle( );
}
