
package org.w3c.dom.svg;

public interface SVGUnitTypes {
  // Unit Types
  public static final short SVG_UNIT_TYPE_UNKNOWN           = 0;
  public static final short SVG_UNIT_TYPE_USERSPACEONUSE    = 1;
  public static final short SVG_UNIT_TYPE_OBJECTBOUNDINGBOX = 2;
}
