
package org.w3c.dom.svg;

public interface SVGLinearGradientElement extends 
               SVGGradientElement {
  public SVGAnimatedLength getX1( );
  public SVGAnimatedLength getY1( );
  public SVGAnimatedLength getX2( );
  public SVGAnimatedLength getY2( );
}
