
package org.w3c.dom.svg;

import org.w3c.dom.events.EventTarget;

public interface SVGDefsElement extends 
               SVGElement,
               SVGTests,
               SVGLangSpace,
               SVGExternalResourcesRequired,
               SVGStylable,
               SVGTransformable,
               EventTarget {
}
