
package org.w3c.dom.svg;

public interface SVGFESpecularLightingElement extends 
               SVGElement,
               SVGFilterPrimitiveStandardAttributes {
  public SVGAnimatedString getIn1( );
  public SVGAnimatedNumber getSurfaceScale( );
  public SVGAnimatedNumber getSpecularConstant( );
  public SVGAnimatedNumber getSpecularExponent( );
}
