
package org.w3c.dom.svg;

public interface SVGFilterPrimitiveStandardAttributes extends 
               SVGStylable {
  public SVGAnimatedLength getX( );
  public SVGAnimatedLength getY( );
  public SVGAnimatedLength getWidth( );
  public SVGAnimatedLength getHeight( );
  public SVGAnimatedString getResult( );
}
