
package org.w3c.dom.svg;

public interface SVGFEImageElement extends 
               SVGElement,
               SVGURIReference,
               SVGLangSpace,
               SVGExternalResourcesRequired,
               SVGFilterPrimitiveStandardAttributes {

  public SVGAnimatedPreserveAspectRatio getPreserveAspectRatio( );

}
