
package org.w3c.dom.svg;

public interface SVGFEPointLightElement extends 
               SVGElement {
  public SVGAnimatedNumber getX( );
  public SVGAnimatedNumber getY( );
  public SVGAnimatedNumber getZ( );
}
