
package org.w3c.dom.svg;

public interface SVGTextPositioningElement extends 
               SVGTextContentElement {
  public SVGAnimatedLengthList getX( );
  public SVGAnimatedLengthList getY( );
  public SVGAnimatedLengthList getDx( );
  public SVGAnimatedLengthList getDy( );
  public SVGAnimatedNumberList getRotate( );
}
