/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// $Id: XMLStreamException.java 670245 2008-06-21 18:03:15Z mrglavas $

package javax.xml.stream;

public class XMLStreamException extends Exception {
    
    private static final long serialVersionUID = 2018819321811497362L;
   
    protected Throwable nested;
    protected Location location;

    public XMLStreamException() {
        super();
    }

    public XMLStreamException(String msg) {
        super(msg);
    }

    public XMLStreamException(Throwable th) {
        this.nested = th;
    }

    public XMLStreamException(String msg, Throwable th) {
        super(msg);
        this.nested = th;
    }

    public XMLStreamException(String msg, Location location,
            Throwable th) {
        super(msg);
        this.location = location;
        this.nested = th;
    }

    public XMLStreamException(String msg, Location location) {
        super(msg);
        this.location = location;
    }

    public Throwable getNestedException() {
        return nested;
    }

    public Location getLocation() {
        return location;
    }
}
