
package org.w3c.dom.svg;

public interface SVGFEOffsetElement extends 
               SVGElement,
               SVGFilterPrimitiveStandardAttributes {
  public SVGAnimatedString getIn1( );
  public SVGAnimatedNumber getDx( );
  public SVGAnimatedNumber getDy( );
}
