
package org.w3c.dom.svg;

public interface SVGClipPathElement extends 
               SVGElement,
               SVGTests,
               SVGLangSpace,
               SVGExternalResourcesRequired,
               SVGStylable,
               SVGTransformable,
               SVGUnitTypes {
  public SVGAnimatedEnumeration getClipPathUnits( );
}
