
package org.w3c.dom.svg;

public interface SVGAnimatedPathData {
  public SVGPathSegList   getPathSegList( );
  public SVGPathSegList   getNormalizedPathSegList( );
  public SVGPathSegList   getAnimatedPathSegList( );
  public SVGPathSegList   getAnimatedNormalizedPathSegList( );
}
