
package org.w3c.dom.svg;

public interface SVGRadialGradientElement extends 
               SVGGradientElement {
  public SVGAnimatedLength getCx( );
  public SVGAnimatedLength getCy( );
  public SVGAnimatedLength getR( );
  public SVGAnimatedLength getFx( );
  public SVGAnimatedLength getFy( );
}
