
package org.w3c.dom.svg;

public interface SVGRenderingIntent {
  // Rendering Intent Types
  public static final short RENDERING_INTENT_UNKNOWN               = 0;
  public static final short RENDERING_INTENT_AUTO                  = 1;
  public static final short RENDERING_INTENT_PERCEPTUAL            = 2;
  public static final short RENDERING_INTENT_RELATIVE_COLORIMETRIC = 3;
  public static final short RENDERING_INTENT_SATURATION            = 4;
  public static final short RENDERING_INTENT_ABSOLUTE_COLORIMETRIC = 5;
}
