
package org.w3c.dom.svg;

public interface SVGFEComponentTransferElement extends 
               SVGElement,
               SVGFilterPrimitiveStandardAttributes {
  public SVGAnimatedString getIn1( );
}
