
package org.w3c.dom.svg;

public interface SVGCursorElement extends 
               SVGElement,
               SVGURIReference,
               SVGTests,
               SVGExternalResourcesRequired {
  public SVGAnimatedLength getX( );
  public SVGAnimatedLength getY( );
}
