package org.w3c.dom.svg;

public interface SVGFEDiffuseLightingElement extends 
               SVGElement,
               SVGFilterPrimitiveStandardAttributes {
  public SVGAnimatedString getIn1( );
  public SVGAnimatedNumber getSurfaceScale( );
  public SVGAnimatedNumber getDiffuseConstant( );
  public SVGAnimatedNumber getKernelUnitLengthX( );
  public SVGAnimatedNumber getKernelUnitLengthY( );
}
